;; Generated package description from vc-got.el  -*- no-byte-compile: t -*-
(define-package "vc-got" "1.2.0.20230129.104658" "VC backend for Game of Trees VCS" '((emacs "25.1")) :commit "66c6e97f4881aff54deff446de40f4cfa696f246" :authors '(("Omar Polo" . "op@omarpolo.com") ("Timo Myyrä" . "timo.myyra@bittivirhe.fi")) :maintainer '(("Omar Polo" . "op@omarpolo.com") ("Timo Myyrä" . "timo.myyra@bittivirhe.fi")) :keywords '("vc" "tools") :url "https://projects.omarpolo.com/vc-got.html")
